[PATCH 1/2] Staging: atm: fix 'endianess' spelling to 'endianness' in fore200e.c This is a patch to the fore200e that fixes the spelling of 'endianess' to the correct one, that is, 'endianness' found by checkpatch.pl tool

rneha725 rneha725 at gmail.com
Thu Mar 10 05:30:38 UTC 2016


Signed-off-by: Neha Rani <rneha725 at gmail.com>
---
 drivers/atm/fore200e.c | 6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)

diff --git a/drivers/atm/fore200e.c b/drivers/atm/fore200e.c
index 75dde90..fac5e4fd 100644
--- a/drivers/atm/fore200e.c
+++ b/drivers/atm/fore200e.c
@@ -409,7 +409,7 @@ fore200e_shutdown(struct fore200e* fore200e)
 static u32 fore200e_pca_read(volatile u32 __iomem *addr)
 {
     /* on big-endian hosts, the board is configured to convert
-       the endianess of slave RAM accesses  */
+       the endianness of slave RAM accesses  */
     return le32_to_cpu(readl(addr));
 }
 
@@ -417,7 +417,7 @@ static u32 fore200e_pca_read(volatile u32 __iomem *addr)
 static void fore200e_pca_write(u32 val, volatile u32 __iomem *addr)
 {
     /* on big-endian hosts, the board is configured to convert
-       the endianess of slave RAM accesses  */
+       the endianness of slave RAM accesses  */
     writel(cpu_to_le32(val), addr);
 }
 
@@ -577,7 +577,7 @@ static int fore200e_pca_configure(struct fore200e *fore200e)
 
     master_ctrl = master_ctrl
 #if defined(__BIG_ENDIAN)
 	/* request the PCA board to convert the endianess of slave RAM accesses */
 	| PCA200E_CTRL_CONVERT_ENDIAN
 #endif
 #if 0
@@ -577,7 +577,7 @@ static int fore200e_pca_configure(struct fore200e *fore200e)
     master_ctrl = master_ctrl
 #if defined(__BIG_ENDIAN)
-	/* request the PCA board to convert the endianess of slave RAM accesses */
+	/* request the PCA board to convert the endianness of slave RAM accesses */
 	| PCA200E_CTRL_CONVERT_ENDIAN
 #endif
-- 
2.5.0



More information about the devel mailing list